@@ -139,9 +139,16 @@ class DarwinFile:
             else:
                 dict_path = resolved_path
             if dict_path in self.machOReferenceForTargetPath:
-                raise DarwinException(
-                    "Multiple dynamic libraries resolved to the same file."
+                if self.strict:
+                    raise DarwinException(
+                        f"ERROR: Multiple dynamic libraries from {self.path}"
+                        f" resolved to the same file ({dict_path})."
+                    )
+                print(
+                    f"WARNING: Multiple dynamic libraries from {self.path}"
+                    f" resolved to the same file ({dict_path})."
                 )
+                continue
             reference = MachOReference(
                 source_file=self,
                 raw_path=raw_path,
@@ -223,7 +230,7 @@ class DarwinFile:
         """Resolve a path that includes @loader_path. @loader_path represents
         the directory in which the DarwinFile is located."""
         if self.isLoaderPath(path):
-            return self.path.parent / path.replace("@loader_path/", "", 1)
+            return self.path.parent / Path(path).relative_to("@loader_path")
         raise DarwinException(f"resolveLoader() called on bad path: {path}")
 
     def resolveExecutable(self, path: str) -> Path:
@@ -231,17 +238,20 @@ class DarwinFile:
         executable was located. By default, we set that to the directory of
         the library, so it would resolve in the same was as if linked from an
         executable in the same directory."""
-        # consider making this resolve to the directory of the target script
-        # instead?
+        # consider making this resolve to the directory of the python
+        # interpreter? Apparently not a big issue in practice, since the
+        # code has been like this forever.
         if self.isExecutablePath(path):
-            return self.path.parent / path.replace("@executable_path/", "", 1)
+            return self.path.parent / Path(path).relative_to(
+                "@executable_path/"
+            )
         raise DarwinException(
             f"resolveExecutable() called on bad path: {path}"
         )
 
     def resolveRPath(self, path: str) -> Optional[Path]:
         for rpath in self.getRPath():
-            test_path = rpath / path.replace("@rpath/", "", 1)
+            test_path = rpath / Path(path).relative_to("@rpath")
             if _isMachOFile(test_path):
                 return test_path
         if not self.strict:
@@ -290,7 +300,16 @@ class DarwinFile:
         test_path = self.path.parent / path
         if _isMachOFile(test_path):
             return test_path.resolve()
-        raise DarwinException(f"Could not resolve path: {path}")
+        if self.strict:
+            raise DarwinException(
+                f"Could not resolve path: {path} from file {self.path}."
+            )
+        print(
+            f"WARNING: Unable to resolve reference to {path} from "
+            f"file {self.path}.  Frozen application may not "
+            f"function correctly."
+        )
+        return None
 
     def resolveLibraryPaths(self):
         for cmd in self.loadCommands:
@@ -495,7 +514,8 @@ def applyAdHocSignature(fileName: str):
 class DarwinFileTracker:
     """Object to track the DarwinFiles that have been added during a freeze."""
 
-    def __init__(self):
+    def __init__(self, strict: bool = False):
+        self.strict = strict
         # list of DarwinFile objects for files being copied into project
         self._copied_file_list: List[DarwinFile] = []
 
@@ -613,18 +633,20 @@ class DarwinFileTracker:
                         )
                         if potential_target is None:
                             # If we cannot find any likely candidate, fail.
+                            if self.strict:
+                                copied_file.printFileInformation()
+                                raise DarwinException(
+                                    f"finalizeReferences() failed to resolve"
+                                    f" path [{reference.raw_path}] in file "
+                                    f"[{copied_file.path}]."
+                                )
                             print(
-                                "\nERROR: Could not resolve RPath "
+                                "\nWARNING: Could not resolve dynamic link to "
                                 f"[{reference.raw_path}] in file "
                                 f"[{copied_file.path}], and could "
-                                "not find any likely intended reference."
-                            )
-                            copied_file.printFileInformation()
-                            raise DarwinException(
-                                f"finalizeReferences() failed to resolve path "
-                                f"[{reference.raw_path}] in file "
-                                f"[{copied_file.path}]."
+                                "not find any likely intended target."
                             )
+                            continue
                         print(
                             f"WARNING: In file [{copied_file.path}]"
                             f" guessing that {reference.raw_path} "
